@@ -28,7 +28,8 @@ import numpy as np
 from time import time
 from collections import OrderedDict
 from iccad_contest.functions.problem import PPAT, DesignSpaceExplorationProblem, \
-	get_adrs, get_pareto_frontier
+	get_adrs_wrt_polytope, get_pareto_frontier
+from iccad_contest.__init__ import __version__
 from iccad_contest.utils.constants import summary_root
 from iccad_contest.utils.serialize import ContestSerializer
 from iccad_contest.utils.arguments import experiment_parser, parse_args, \
@@ -43,7 +44,7 @@ logger = None
 def initialize_logger(output_path, uuid):
 	global logger
 	log_file = ContestSerializer.logging_path(output_path, uuid)
-	logger = create_logger(__name__, log_file)
+	logger = create_logger(log_file)
 	return logger
 
 
@@ -205,7 +206,7 @@ def do_experiment_impl(
 			"current ADRS: {} " \
 			"cost: {}.".format(
 				i + 1,
-				get_adrs(
+				get_adrs_wrt_polytope(
 					problem.pareto_frontier,
 					get_pareto_frontier(
 						torch.Tensor(objective_values)
@@ -222,7 +223,7 @@ def do_experiment_impl(
 		if optimizer.early_stopping:
 			break
 
-	adrs = get_adrs(
+	adrs = get_adrs_wrt_polytope(
 		problem.pareto_frontier,
 		get_pareto_frontier(
 			torch.Tensor(objective_values)
@@ -298,6 +299,7 @@ def experiment(solution):
 	"""
 	args = parse_experiment_args()
 	logger = initialize_logger(args["output_path"], args["uuid"])
+	logger.info("[INFO]: Prolem C @ ICCAD'22 contest platform version: {}".format(__version__))
 	solution_settings = load_solution_settings(args["solution_settings"])
 	if solution_settings == {}:
 		logger.info("[INFO]: no --solution-settings is specified.")
