@@ -15,6 +15,7 @@
 
 import torch
 import numpy as np
+from itertools import combinations
 from abc import ABC, abstractmethod
 from scipy import stats
 from iccad_contest.functions.design_space import parse_contest_design_space
@@ -81,7 +82,6 @@ class DesignSpaceExplorationProblem(Problem):
         self.design_space = parse_contest_design_space()
         self.dataset = load_contest_dataset()
         self.dim_of_objective_values = dim_of_objective_values
-        self.idx = self.dataset[:, 0]
         self.microarchitecture_embedding_set = self.dataset[
             :, :-(dim_of_objective_values + 1)
         ]
@@ -189,8 +189,42 @@ def get_adrs(reference_pareto_frontier, predict_pareto_frontier):
     predict_pareto_frontier = predict_pareto_frontier.cpu()
     for omega in reference_pareto_frontier:
         mini = float('inf')
-        for gama in predict_pareto_frontier:
-            mini = min(mini, np.linalg.norm(omega - gama))
+        for gamma in predict_pareto_frontier:
+            mini = min(mini, np.linalg.norm(omega - gamma))
         adrs += mini
     adrs = adrs / len(reference_pareto_frontier)
     return adrs
+
+
+def get_adrs_wrt_polytope(reference_pareto_frontier, predict_pareto_frontier):
+    """
+        reference_pareto_frontier: <torch.Tensor>
+        predict_pareto_frontier: <torch.Tensor>
+    """
+    def calc_dist_wrt_linseg(p, p1, p2):
+        # get the normalized tangent vector
+        d = np.divide(p2 - p1, np.linalg.norm(p2 - p1))
+        # get the signed parallel distance components
+        s = np.dot(p1 - p, d)
+        t = np.dot(p - p2, d)
+        # get the clamped parallel distance
+        h = np.maximum.reduce([s, t, 0])
+        # get perpendicular distance component
+        c = np.cross(p - p1, d)
+
+        return np.hypot(h, np.linalg.norm(c))
+
+    # calculate average distance to the `reference_pareto_frontier` set
+    assert isinstance(reference_pareto_frontier, torch.Tensor) and \
+        isinstance(reference_pareto_frontier, torch.Tensor), \
+            assert_error("please convert the input to 'torch.Tensor.")
+    adrs = 0
+    i = 0
+    for p1, p2 in combinations(reference_pareto_frontier, 2):
+        mini = float('inf')
+        for gamma in predict_pareto_frontier:
+            mini = min(mini, calc_dist_wrt_linseg(gamma.numpy(), p1.numpy(), p2.numpy()))
+        adrs += mini
+        i += 1
+    adrs /= i
+    return adrs
